While custom URL schemes are an acceptable form of deep linking, universal links are strongly recommended. For more
information on universal links, see Allowing Apps and Websites to Link to Your Content.

App need to make sure to validate all URL parameters and discard any
malformed URLs. In addition, limit the available actions to those that don’t risk the user’s data. For example, don’t
allow other apps to directly delete content or access sensitive information about the user.
